package com.compomics.scripts_marc;

import java.io.BufferedReader;
import java.io.BufferedWriter;
import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileReader;
import java.io.FileWriter;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;

/**
 *
 * @author Marc Vaudel
 */
public class MaxQuantGrouping {

    private static final String separator = "\t";

    public static void main(String[] args) {

        MaxQuantGrouping m = new MaxQuantGrouping();

        try {
            System.out.println("merging proteins");
            m.groupProjectsProteins();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public void groupProjectsProteins() throws FileNotFoundException, IOException {

        HashMap<String, String> lfAccessions = new HashMap<String, String>();
        HashMap<String, String> lfPValues = new HashMap<String, String>();
        HashMap<String, String> lfFCs = new HashMap<String, String>();
        HashMap<String, String> lfFCSignificances = new HashMap<String, String>();

        BufferedReader br = new BufferedReader(new FileReader(new File("D:\\projects\\Fresh Frozen\\lf.txt")));
        String line = br.readLine();
        while ((line = br.readLine()) != null) {
            String[] components = line.split(separator);
            String accession = components[0];
            String[] accessionSplit = accession.split(";");
            String key = getKey(accessionSplit);
            if (lfAccessions.containsKey(key)) {
                throw new IllegalArgumentException("Duplicate Key " + key);
            }
            lfAccessions.put(key, accession);
            lfPValues.put(key, components[13]);
            lfFCs.put(key, components[21]);
            lfFCSignificances.put(key, components[22]);
        }
        br.close();

        HashMap<String, String> silacAccessions = new HashMap<String, String>();
        HashMap<String, String> silacPValues = new HashMap<String, String>();
        HashMap<String, String> silacFCs = new HashMap<String, String>();
        HashMap<String, String> silacFCSignificances = new HashMap<String, String>();

        br = new BufferedReader(new FileReader(new File("D:\\projects\\Fresh Frozen\\silac.txt")));
        line = br.readLine();
        while ((line = br.readLine()) != null) {
            String[] components = line.split(separator);
            String accession = components[0];
            String[] accessionSplit = accession.split(";");
            String key = getKey(accessionSplit);
            if (silacAccessions.containsKey(key)) {
                throw new IllegalArgumentException("Duplicate Key " + key);
            }
            silacAccessions.put(key, accession);
            silacPValues.put(key, components[9]);
            silacFCs.put(key, components[14]);
            silacFCSignificances.put(key, components[15]);
        }
        br.close();
        
        HashSet<String> accessionsSet = new HashSet<String>(silacAccessions.keySet());
        accessionsSet.addAll(lfAccessions.keySet());
        BufferedWriter bw = new BufferedWriter(new FileWriter(new File("D:\\projects\\Fresh Frozen\\combined.txt")));
        bw.write("Accession" + separator + "LF p-value" + separator + "LF FC" + separator + "LF FC p" + separator + "SILAC p-value" + separator + "SILAC FC" + separator + "SILAC FC p");
        bw.newLine();
        for (String accession : accessionsSet) {
            String accessionMQ = lfAccessions.get(accession);
            if (accessionMQ == null) {
                accessionMQ = silacAccessions.get(accession);
            }
            String lfP = lfPValues.get(accession);
            if (lfP == null) {
                lfP = "";
            }
            String lfFC = lfFCs.get(accession);
            if (lfFC == null) {
                lfFC = "";
            }
            String lfFCp = lfFCSignificances.get(accession);
            if (lfFCp == null) {
                lfFCp = "";
            }
            String silacP = silacPValues.get(accession);
            if (silacP == null) {
                silacP = "";
            }
            String silacFC = silacFCs.get(accession);
            if (silacFC == null) {
                silacFC = "";
            }
            String silacFCp = silacFCSignificances.get(accession);
            if (silacFCp == null) {
                silacFCp = "";
            }
            bw.write(accessionMQ + separator + lfP + separator + lfFC + separator + lfFCp + separator + silacP + separator + silacFC + separator + silacFCp);
            bw.newLine();
        }
        bw.close();

    }

    public String getKey(String[] accessions) {
        HashSet<String> accessionsSet = new HashSet<String>(accessions.length);
        accessionsSet.addAll(Arrays.asList(accessions));
        ArrayList<String> accessionsList = new ArrayList<String>(accessionsSet);
        Collections.sort(accessionsList);
        StringBuilder result = new StringBuilder();
        for (String accession : accessionsList) {
            if (result.length() > 0) {
                result.append("_");
            }
            result.append(accession);
        }
        return result.toString();
    }
}
